//
//
// analysis.C
//
// 

#include <iomanip>

TFile foutp;

int Romeo(const TString &fname="test")
{

  gROOT->Reset();

  gSystem->Load("libPhysics.so");
  gSystem->Load("../lib/libRMOKernel.so");
  gSystem->Load("../lib/libRMOGlassGel.so");
  gSystem->Load("../lib/libRMOPMT.so");
  gSystem->Load("../lib/libI3OMAnalog.so");
    
  TString outname(fname);
  outname += ".root";
  cerr << "outputname = " << outname << endl;

  foutp = new TFile(outname,"RECREATE");

  gStyle->SetOptStat(0);
  gStyle->SetPalette(1);
  gStyle->SetCanvasColor(33);
  gStyle->SetFrameFillColor(18);
  
  // create modules ...
  
  Double_t hv = 2000;

  I3OMAnalog           *omanalog  = new I3OMAnalog();  
  RMOPMTPhotoCathode   *cathode   = new RMOPMTPhotoCathode();
  RMOPMTChargeResponse *qresponse = new RMOPMTChargeResponse(hv);
  RMOPMTWaveForm       *waveform  = new RMOPMTWaveForm();

  // set verbose...
  // 0 : no output
  // 1 : default
  // 2 : function called
  // 3 : precise
  // 4 : debug

  omanalog->SetVerboseLevel(4);
  cathode->SetVerboseLevel(1);
  qresponse->SetVerboseLevel(1);
  waveform->SetVerboseLevel(4);

  // add modules...
  
  omanalog->Add(cathode);
  omanalog->Add(qresponse);
  omanalog->Add(waveform);

  // configure...

  omanalog->ExecuteTask("Configure");

  // process...

  ifstream in("photons.data");
  TVector3 pos, dir;

  Int_t evt = 0;
  RMOPhotonBuf photonarray;
  Double_t x, y, z;
  while ( in >> x >> y >> z ) {
     pos(0) = x * 0.001;  // mm -> m
     pos(1) = y * 0.001;
     pos(2) = z * 0.001;

     RMOOpticalPhoton *photon = new RMOOpticalPhoton(pos, dir);
     photonarray.Add(photon);
     evt ++;
     if (evt > 10) break;
  }
  omanalog->SetBuffer(&photonarray);
  omanalog->ExecuteTask("Process");

  // finish...

  omanalog->ExecuteTask("Finish");

  // Draw...

  omanalog->ExecuteTask("Draw");

  foutp->Write();
}



