//
//
// RomeoDemo.C
//
// 

#include <TRandom.h>
#include <iomanip.h>
#include <TMath.h>

//TFile foutp;

int RomeoDemo()
{

  gROOT->Reset();

  gSystem->Load("libPhysics.so");
  gSystem->Load("../lib/libRMONumericalRecipes.so");
  gSystem->Load("../lib/libRMOKernel.so");
  gSystem->Load("../lib/libRMOGlassGel.so");
  gSystem->Load("../lib/libRMOPMT.so");
  gSystem->Load("../lib/libI3OMAnalog.so");
    
  //TString outname(fname);
  //outname += ".root";
  //cerr << "outputname = " << outname << endl;

  //foutp = new TFile(outname,"RECREATE");

  gStyle->SetOptStat(0);
  gStyle->SetPalette(1);
  gStyle->SetCanvasColor(33);
  gStyle->SetFrameFillColor(18);
  
  // create modules ...
  

  I3OMAnalog               *omanalog  = new I3OMAnalog();  
  RMOWaveLengthSimulator   *wlsim     = new RMOWaveLengthSimulator();
  RMOQuickPhotonPropagator *phprop    = new RMOQuickPhotonPropagator();
  RMOPMTPhotoCathode       *cathode   = new RMOPMTPhotoCathode("TA0532.table");
  RMOPMTChargeResponse     *qresponse = new RMOPMTChargeResponse();
  RMOPMTWaveForm           *waveform  = new RMOPMTWaveForm();

  // set verbose...
  // 0 : no output
  // 1 : default
  // 2 : function called
  // 3 : precise
  // 4 : debug

  omanalog->SetVerboseLevel(4);
  wlsim->SetVerboseLevel(4);
  phprop->SetVerboseLevel(4);
  cathode->SetVerboseLevel(4);
  qresponse->SetVerboseLevel(4);
  waveform->SetVerboseLevel(4);

  // add modules...
  
  omanalog->Add(wlsim);
  omanalog->Add(phprop);
  omanalog->Add(cathode);
  omanalog->Add(qresponse);
  omanalog->Add(waveform);

  // create calib files...
  // If you have calibfiles already, skip this line

  if (gSystem->AccessPathName("QuickPhotonPropagatorMap.root")) {
     phprop->MakeQuickPhotonPropagatorMap("QuickPhotonPropagatorMap.data");
  }

  // configure...

  omanalog->ExecuteTask("Configure");

  // process...

  Int_t evt = 0;
  RMOMCPhotonHitBuf hitarray;
  //Int_t maxevt = 20;
  Int_t maxevt = 100;

  for(evt=0; evt<maxevt; evt++){

    Double_t tau  = 5.e-9;   // 5ns
    Double_t time = gRandom->Exp(tau);
    Double_t dist = 50;      // 50m
    TVector3 dir(-1, -1, 0);
    //TVector3 dir(-1, 0, -1);
    //TVector3 dir(1, 1, -1);
    //TVector3 dir(1, 1, 0);

    RMOMCPhotonHit *hit = new RMOMCPhotonHit();
    hit->SetTime(time);
    hit->SetDirection(dir);
    hit->SetDistanceFromSource(dist);
    hitarray.Add(hit);
  }

  omanalog->SetBuffer(&hitarray);
  omanalog->ExecuteTask("Process");

  // finish...

  omanalog->ExecuteTask("Finish");

  // Draw...

  omanalog->ExecuteTask("Draw");

  //foutp->Write();
}



