// $Id: RMOQuickPhotonPropagator.h,v 1.5 2004/10/05 18:32:07 hoshina Exp $
#ifndef __RMOQuickPhotonPropagator__H__
#define __RMOQuickPhotonPropagator__H__

//*************************************************************************
//* ---------------------
//* RMOQuickPhotonPropagator Class
//* ---------------------
//* (Description)
//*     Quick photon propagator from the surface of glass to 
//*     the surface of PMT.
//*     The imput photons are spread on the PMT surface under
//*     the arrival map of photons generated by DOMINANT.
//*     Note that THE MODULE DOES NOT ELIMINATE ANY PHOTON.
//*     Number of the imput photons must be calcurated with
//*     taking into account of absorption at glass and gel, 
//*     reflection and refraction, and angle acceptance. 
//*     
//* (Requires)
//*	RMOOpticalPhoton
//*	RMOPhotonBuf
//* (Provides)
//*	RMOQuickPhotonPropagator              : Quick photon propagator module
//* (Update Record)
//*	2004/09/22  K.Hoshina	Original version.
//*************************************************************************

#include "RMOVModule.h"
#include "RMOPhotonBuf.h"
#include "RMOOpticalPhoton.h"
#include "TH3D.h"
#include "TFile.h"
#include "TCanvas.h"
#include "TVector3.h"

class RMOQuickPhotonPropagator : public RMOVModule {

public:

  RMOQuickPhotonPropagator();
  RMOQuickPhotonPropagator(const TString &calibfilename);

  virtual ~RMOQuickPhotonPropagator();

  virtual void     Configure();
  virtual void     Draw();
  virtual void     Finish();
  static  TString  GetCalibFileName()     { return fCalibFileName; }
  static  TString  GetCalibRootFileName() { return fCalibRootFileName; }
  virtual const TObject &GetBuffer() const { return *fOutputPhotonBuf; }
  static TVector3  GetRandomPosition(RMOOpticalPhoton *iph, const TString &dirname,
                                     Bool_t isglobal, EVerboseLevel verbose);
  static  void     MakeQuickPhotonPropagatorMap(const TString &fname
                                              = "QuickPhotonPropagatorMap.data");
  virtual void     Process();
  static  void     SetCalibFileNames(const TString &fname); 
  virtual void     SetRefHistName(const TString &name) { fRefHistName = name; }

private:

  static Double_t fCenter_of_pmt_z;      // z position of pmt center
  static TString  fCalibFileName;        // calibration file name
  static TString  fCalibRootFileName;    // calibration file name

  TString       fRefHistName;       // reference histgram name
  TFile        *fCalibFile;         // pointer to calibration file

  TH3D         *fPhotonHist;        // arrived photon hist
  RMOPhotonBuf *fOutputPhotonBuf;   // buffer of photons
  TCanvas      *fCanvas;            // Canvas for arrival photon histgram

  ClassDef(RMOQuickPhotonPropagator, 1)    // abstract base class for modules

};

//---------------------
// inline functions
//---------------------


#endif

