// $Id: RMOWaveLengthSimulator.h,v 1.2 2004/10/05 18:32:07 hoshina Exp $
#ifndef __RMOWaveLengthSimulator__H__
#define __RMOWaveLengthSimulator__H__

//*************************************************************************
//* ---------------------
//* RMOWaveLengthSimulator Class
//* ---------------------
//* (Description)
//*     It simulates wave length spectrum of Cerenkov photons
//*     after X[m] propagation in Antiarctic ice.
//*     
//* (Requires)
//*	RMOPhotonHitBuf
//*	RMOOpticalPhoton
//* (Provides)
//*	RMOWaveLengthSimulator   : wave length simulation module           
//* (Update Record)
//*	2004/09/22  K.Hoshina	Original version.
//*************************************************************************

#include "RMOVModule.h"
#include "RMOPhotonBuf.h"
#include "TH1D.h"
#include "TF1.h"
#include "TCanvas.h"

class RMOWaveLengthSimulator : public RMOVModule {

public:

  RMOWaveLengthSimulator();

  virtual ~RMOWaveLengthSimulator();

  virtual void  Configure();
  virtual void  Draw();
  virtual void  Finish();
  virtual const TObject &GetBuffer() const { return *fOutputPhotonBuf; }
  virtual void  Process();


private:

  static const Double_t  kLambdaMin;     // min lambda
  static const Double_t  kLambdaMax;     // max lambda
  static const Double_t  kLambdaMinQE;   // min edge of QE curve
  static const Double_t  kLambdaMaxQE;   // max edge of QE curve

  TF1          *fCerenkovWaveLengthSpectrum;  // 
  TF1          *fWaveLengthSpectrumAtX;       //
  TH1D         *fWaveLengthHist;              //

  RMOPhotonBuf *fOutputPhotonBuf;   // buffer of photons
  TCanvas      *fCanvas;            // Canvas for arrival photon histgram

  ClassDef(RMOWaveLengthSimulator, 1)    // WaveLength simulator

};

#endif

