// $Id: RMOElectron.cxx,v 1.4 2004/10/05 18:16:35 hoshina Exp $
//*************************************************************************
//* --------------------
//* RMOElectron
//* --------------------
//* (Description)
//*     Particle class which represents an electron.	
//* (Update Record)
//*	2003/12/22  K.Hoshina	Original version.
//*************************************************************************

#include "RMOElectron.h"

ClassImp(RMOElectron)

using namespace std;

const TString  RMOElectron::kParticleName = "Electron";
const Double_t RMOElectron::kRestMass     = 0.511;       // MeV
const Double_t RMOElectron::kCharge       = -1.0;

//=====================================================================
//* constructor -------------------------------------------------------

RMOElectron::RMOElectron()
            :RMOVParticle(), RMOVAttDatum()
{
  fCosTheta = 1.0;
  fAzimuthAngle = 0.0;
}

RMOElectron::RMOElectron(const TVector3 &pos, const TVector3 &dir)
            :RMOVParticle(pos, dir) , RMOVAttDatum()
{
  fCosTheta = 1.0;
  fAzimuthAngle = 0.0;
}

//=====================================================================
//* destructor --------------------------------------------------------

RMOElectron::~RMOElectron()
{
}

//=====================================================================
//* Setting the cosine  -----------------------------------------------

void RMOElectron::SetCosTheta(Double_t cosTheta)
{
  if(TMath::Abs(cosTheta)<=1.0){
    fCosTheta = cosTheta;
  }else{
    cerr << "Invalid cosine (" << cosTheta << ")" << endl;
    cerr << "Cosine unchanged (" << fCosTheta << ")" << endl;
  }
}

//=====================================================================
//* Setting the Azimuth Angle  ----------------------------------------
//* alpha: Azimuth Angle [rad] ----------------------------------------

void RMOElectron::SetAzimuth(Double_t alpha)
{
  if(0.0<= alpha && alpha<=2.0*TMath::Pi()){
    fAzimuthAngle = alpha;
  }else{
    cerr << "Invalid azimuth (" << alpha*TMath::RadToDeg() 
	 << ") [deg]"  << endl;
    cerr << "Cosine unchanged (" << fAzimuthAngle*TMath::RadToDeg()
	 << ") [deg]"  << endl;
  }
}

