// $Id: RMOElectron.h,v 1.4 2004/10/05 18:16:35 hoshina Exp $
#ifndef __RMOElectron__H__
#define __RMOElectron__H__

//*************************************************************************
//* ---------------------
//* RMOElectron Class
//* ---------------------
//* (Description)
//*     Particle class for an electron.
//* (Requires)
//*     RMOVParticle
//* (Provides)
//*	RMOElectron              
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*     2004/8/23   S.Yoshida   The cathode coordinate field added
//*************************************************************************

#include "RMOVParticle.h"
#include "RMOVAttDatum.h"

class RMOElectron : public RMOVParticle , public RMOVAttDatum {

public:

  RMOElectron();
  RMOElectron(const TVector3 &pos, const TVector3 &dir);

  virtual ~RMOElectron();
  virtual void      DumpInfo(Option_t *opt) {}

  Double_t GetCosTheta() const { return fCosTheta; }
  Double_t GetAzimuth()  const { return fAzimuthAngle; }

  // *** TEMPORARY METHODS !! ***
  void     SetCosTheta(Double_t cosTheta);
  void     SetAzimuth(Double_t alpha);
  // ****************************

  static  Double_t  GetCharge()       { return kCharge;       }
  static  TString   GetParticleName() { return kParticleName; }
  static  Double_t  GetRestMass()     { return kRestMass;     }

private:

  static const TString  kParticleName;   // particle name = "Electron"
  static const Double_t kRestMass;       // rest mass of the particle
  static const Double_t kCharge;         // charge of the particle

  Double_t        fCosTheta;       // cosine of theta on the cathode coordinate
  Double_t        fAzimuthAngle;   // Azimuth angle [rad] on the cathode coordinate

  ClassDef(RMOElectron, 1)         // electron class

};

#endif
