// $Id: RMOOpticalPhoton.h,v 1.6 2004/10/05 18:16:35 hoshina Exp $
#ifndef __RMOOpticalPhoton__H__
#define __RMOOpticalPhoton__H__

//*************************************************************************
//* ---------------------
//* RMOOpticalPhoton Class
//* ---------------------
//* (Description)
//*     Particle class for an optical photon
//* (Requires)
//*     RMVParticle
//* (Provides)
//*	RMOOpticalPhoton              
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*     2004/8/23   S.Yoshida   Adding the wavelength/ 
//*                             the cathode coordinate field
//*************************************************************************

#include "RMOVParticle.h"
#include "RMOVAttDatum.h"

class RMOOpticalPhoton : public RMOVParticle, public RMOVAttDatum {

public:

  RMOOpticalPhoton();
  RMOOpticalPhoton(const TVector3 &pos,
                   const TVector3 &dir);

  virtual ~RMOOpticalPhoton();

  virtual void     DumpInfo(Option_t *opt) {}
  virtual Double_t GetAzimuth()  const      { return fAzimuthAngle; }
  static  Double_t GetCharge()              { return kCharge;       }
  virtual Double_t GetCosTheta() const      { return fCosTheta; }
  static  TString  GetParticleName()        { return kParticleName; }
  virtual Double_t GetWaveLength()   const  { return fWaveLength;   }
  virtual Bool_t   IsValidWaveLength(Double_t lambda) const;
  virtual void     SetAzimuth(Double_t alpha);
  virtual void     SetCosTheta(Double_t cosTheta);
  virtual void     SetWaveLength(Double_t lambda);


private:

  static const TString  kParticleName;   // particle name = "OpticalPhoton"
  static const Double_t kCharge;         // charge of the particle
  static const Double_t kMaxWaveLength;  // Maximum Wavelength allowed [m]
  static const Double_t kMinWaveLength;  // Minimum Wavelength allowed [m]

  Double_t              fWaveLength;     // WaveLength [m]
  Double_t              fCosTheta;       // cosine of theta on the cathode coordinate
  Double_t              fAzimuthAngle;   // Azimuth angle [rad] on the cathode coordinate

  ClassDef(RMOOpticalPhoton, 1)     // Optical photon class

};

#endif
