// $Id: RMOVFunction.h,v 1.2 2004/10/05 18:16:35 hoshina Exp $
#ifndef __RMOVFunction__H__
#define __RMOVFunction__H__

//*************************************************************************
//* ---------------------
//* RMOVFunction Class
//* ---------------------
//* (Description)
//*     Abstract function class.
//*     A class function "Function(double* double*)" is set to the 
//*     TF1 object instead of a global user function.
//* (Requires)
//* (Provides)
//*	RMOVFunction              : base class for modules
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*************************************************************************


#include <TF1.h>
#include <iostream>
#include <fstream>

#include "RMOEnumDef.h"
#include "RMOUnit.h"
#include "RMOAttVerbose.h"
#include "RMOVBuffer.h"

class RMOVFunction : public TF1 {

public:

   RMOVFunction() : TF1() {}

   RMOVFunction(const char* name, Double_t xmin=0, 
                Double_t xmax=1.0e-7, Int_t npar=0);

   virtual ~RMOVFunction();

   virtual TF1         *DrawCopy(Option_t *option) const = 0;
   virtual Double_t     Eval(Double_t x, Double_t y = 0, Double_t z = 0, Double_t t = 0);
   virtual Double_t     EvalPar(const Double_t *x, const Double_t *params=0);
   virtual Double_t     Function(Double_t *x, Double_t *par) = 0;
   static RMOVFunction* GetCurrentFunction() { return fgCurFunc; }
   virtual void         SavePrimitive(ofstream &out, Option_t *option) = 0;
   static  void         SetCurrentFunction(RMOVFunction *cur) { fgCurFunc = cur; }
  
private:

   static RMOVFunction * fgCurFunc;     // current function

   ClassDef(RMOVFunction, 1)            // abstract base class for modules

};

//=====================================
// inline function
//=====================================

#endif

