// $Id: RMOVModule.cxx,v 1.3 2004/10/04 03:33:43 hoshina Exp $
//*************************************************************************
//* --------------------
//* RMOVModule
//* --------------------
//* (Description)
//*	Abstract base class for RMO modules.
//* (Requires)
//* (Provides)
//* (Update Record)
//*	2003/12/22  K.Hoshina	Original version.
//*************************************************************************

#include "RMOVModule.h"

ClassImp(RMOVModule)

using namespace std;

EState      RMOVModule::fgState    = kALIVE;
RMOVModule* RMOVModule::fgLastTask = 0;

//=====================================================================
//* constructor -------------------------------------------------------

RMOVModule::RMOVModule(const char *name, const char *title)
       			: TTask(name,title), RMOAttVerbose()
{
//*-*-*-*-*-*-*-*-*-*Constructor for module*-*-*-*-*-*-*-*-*-*-*
//                  =======================

   VerbosePrint(TString("RMOVModule::constructor of ") + GetName() 
                + "is called", kDEBUG);
}

//=====================================================================
//* destructor --------------------------------------------------------

RMOVModule::~RMOVModule()
{
//*-*-*-*-*-*-*-*-*-*Destructor for module*-*-*-*-*-*-*-*-*-*-*
//                   =====================
}

//=====================================================================
//* Add ---------------------------------------------------------------

void RMOVModule::Add(RMOVModule *module)
{
//*-*-*-*-*-*-*-*-*-*-*-*Add sub module*-*-*-*-*-*-*-*-*-*-*-*
//                       ==============
//  Use this Add method instead of TTask::Add, in order to 
//  set mother module at once.

    VerbosePrint(TString("RMOVModule::Add: ") + module->GetName()
                         + " is added to " + GetName(), kDEBUG);
    TTask::Add(module);
    module->SetMother(this);
}

void RMOVModule::Add(TTask *module)
{
//  Use RMOVModule::Add(RMOVModule *module) 
//  instead of it.
    
    cerr << "RMOVModule::Add: Use Other Add() function. abort." << endl;
    abort();
}

//=====================================================================
//* Exec --------------------------------------------------------------

void RMOVModule::Exec(Option_t *opt)
{
//*-*-*-*-*-*-*-*-*-*-*-*Execute task*-*-*-*-*-*-*-*-*-*-*-*-*
//                       ============
//  The Exec function is called by ExecuteTask() or ExecuteTasks() 
//  automatically. 
//  Options must be one of pure-virtual method. 
//  Current options are:
//     Configure : for configuration all modules
//     Process   : main process 
//     Finish    : executed at the end of run 
//     Draw      : Draw histgrams 
//  
//*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*

   if (fgBeginTask == this) fgState = kALIVE;
   if (fgState != kALIVE) return;

   TString option(opt);

   if (option == "Configure") {
      VerbosePrint(TString("RMOVModule::Exec: Configure of ")
                   + GetName() + " is called!", kFUNCTION_CALLED);
      Configure();

   } else if (option == "Process") {
      VerbosePrint(TString("RMOVModule::Exec: Process of ")
                   + GetName() + " is called!", kFUNCTION_CALLED);
      Process();

   } else if (option == "Finish") {  
      VerbosePrint(TString("RMOVModule::Exec: Finish of ")
                   + GetName() + " is called!", kFUNCTION_CALLED);
      Finish();

   } else if (option == "Draw") {  
      VerbosePrint(TString("RMOVModule::Exec: Draw of ")
                   + GetName() + " is called!", kFUNCTION_CALLED);
      Draw();
   }

   if (fgState != kALIVE) {
      switch (fgState) { 
         case kVANISHED:
            VerbosePrint(TString("RMOVModule::Exec:  The particle vanished at ")
                         + GetName(), kPRECISE);
            break;
         case kABSORBED:
            VerbosePrint(TString("RMOVModule::Exec:  The particle absorbed at ")
                         + GetName(), kPRECISE);
            break;
         case kABORTED:
            VerbosePrint(TString("RMOVModule::Exec:  The program is aborted at ")
                         + GetName(), kPRECISE);
            break;
         default:
            VerbosePrint(TString("RMOVModule::Exec:  Wrong Code! something strange happen ")
                         + GetName(), kPRECISE);
            break;
      }
   }
   fgLastTask = this;
}

//=====================================================================
//* GetBuffer ---------------------------------------------------------

const TObject& RMOVModule::GetImputBuffer()
{
//*-*-*-*-*-*-*-*-*-*-*-*Return buffer*-*-*-*-*-*-*-*-*-*-*-*-*
//                       =============
//  It returns reference to imput buffer associeted with forward task(RMOVModule).
//  If the module is first task, it returns buffer of mother task.
//     
//*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*

   RMOVModule *pre = (RMOVModule *)GetMother()->GetListOfTasks()->Before(this);
   if (!pre) pre = GetMother();
   return pre->GetBuffer();

}


