#ifndef __RMOPMT2DCollectEff__H__
#define __RMOPMT2DCollectEff__H__

//*************************************************************************
//* ---------------------
//* RMOPMT2DCollectEff Class
//* ---------------------
//* (Description)
//*     module class for PMT Qe
//* (Requires)
//* (Provides)
//*	RMOPMT2DCollectEff              : 2D CollectionEfficiency modules
//* (Update Record)
//*	2004/8/16  S.Yoshida	Original version.
//*************************************************************************
#include <iostream>
#include <fstream>
#include <TH2D.h>
#include <TCanvas.h>
#include <TArrayD.h>

#include "RMOVDatum.h"

class RMOPMT2DCollectEff : public RMOVDatum {

public:

  RMOPMT2DCollectEff();
  RMOPMT2DCollectEff(TString& fileName);

  virtual ~RMOPMT2DCollectEff();

  void Draw();

  Double_t      CosZenithToDistance(Double_t cos_th);
  Double_t      Get2DCollectEff(Double_t azimuthAngle, Double_t cosZeinith);
  void          SetScale(Double_t scale) { fScale = scale; }
  TString       GetPMTName() const       { return  fPMTName; }
  virtual void  DumpInfo(Option_t *opt) {}


private:

  void ReadCETable( );
  void NormalizeCollectEff();         // Normalize the CE so that
                                      // the average over solid angle is 100 %

  Double_t GetDistanceMax() const;    // Maximum range of allowed distance along
                                      // the R-guid. Limited by the measured data.

  inline Double_t GetDistanceMin() const { return 0.0; }; 
                                      // Minimm range of allowed distance along
                                      // the R-guid. Limited by the measured data.
  Bool_t IsValidDistance(Double_t l) const;


  static const Int_t    kNXbins;    // No of Xbins of CEMap
  static const Int_t    kNYbins;    // No of Ybins of CEMap 
  static const Double_t kXmin;      // min of X-axis of CEMap
  static const Double_t kXmax;      // max of X-axis of CEMap
  static const Double_t kYmin;      // min of Y-axis of CEMap
  static const Double_t kYmax;      // max of Y-axis of CEMap
  static const Double_t kR_pmt;        // Radius of the PMT Curvature
  static const Int_t    kDegOfPolynominal;        // degree of Polynominal interpolation
 
  enum { kNumber_of_azimuth = 33, kNumber_of_distance = 133 };

  TString   fCeDataName;     // name of correction efficiency data
  TArrayD*  fCETable;        // Collection Efficiency data
  TArrayD*  fDistanceTable;  // Distance data
  TArrayD*  fAzimuthTable;   // Azimuth angle data
  TArrayI*  fNumberTable;    // Number of the data point
  TH2D*     fCEMap;          // 2D histogram of Collection Efficiency
  TCanvas*  fCanvas;         // canvas for histograms
  TString   fPMTName;        // Name of the PMT
  Double_t  fScale;          // Renomalization Scale. For accounting PMT individual variances.
  Double_t  fNorm;           // 


  ClassDef(RMOPMT2DCollectEff, 1)    // Optical photon class

};

#endif
