#ifndef __RMOPMT2DGain__H__
#define __RMOPMT2DGain__H__

//*************************************************************************
//* ---------------------
//* RMOPMT2DGain Class
//* ---------------------
//* (Description)
//*     module class for PMT Gain
//* (Requires)
//* (Provides)
//*	RMOPMT2DGain              : 2D Gain modules
//* (Update Record)
//*	2004/8/25  S.Yoshida	Original version.
//*************************************************************************
#include <iostream>
#include <fstream>
#include <TH2D.h>
#include <TCanvas.h>
#include <TArrayD.h>

#include "RMOVDatum.h"

class RMOPMT2DGain : public RMOVDatum {

public:

  RMOPMT2DGain(): RMOVDatum(),fGainMap(0),
    fGainDataName("TA0451_gain.table"),fGainTable(0), 
    fDistanceTable(0), fAzimuthTable(0), fNumberTable(0),fCanvas(0){
    fScale = 1.0; fNorm = 1.0;
    ReadGainTable();
  }

  RMOPMT2DGain(TString& fileName);

  virtual ~RMOPMT2DGain();

  void Draw();
  void MakeMapWithoutDraw();

  Double_t      CosZenithToDistance(Double_t cos_th);
  Double_t      Get2DGain(Double_t azimuthAngle, Double_t cosZeinith);
  void          SetScale(Double_t scale){ fScale = scale;}
  TString       GetPMTName() const { return  fPMTName;}
  virtual void  DumpInfo(Option_t *opt) {}

  TH2D*         fGainMap;      // 2D histogram of Collection Efficiency

private:

  void ReadGainTable( );
  void NormalizeGain();        // Normalize the Gain so that
                               // the average over solid angle is 100 %

  Double_t GetDistanceMax() const;    // Maximum range of allowed distance along
                                      // the R-guid. Limited by the measured data.

  inline Double_t GetDistanceMin() const {return 0.0;}; 
                                       // Minimm range of allowed distance along
                                       // the R-guid. Limited by the measured data.

  Bool_t IsValidDistance(Double_t l) const;


private:

  static const Int_t    kNXbins;    // No of Xbins of GainMap
  static const Int_t    kNYbins;    // No of Ybins of GainMap 
  static const Double_t kXmin;      // min of X-axis of GainMap
  static const Double_t kXmax;      // max of X-axis of GainMap
  static const Double_t kYmin;      // min of Y-axis of GainMap
  static const Double_t kYmax;      // max of Y-axis of GainMap
  static const Double_t kR_pmt;     // Radius of the PMT Curvature
  static const Int_t    kDegOfPolynominal;   // degree of Polynominal interpolation
 
  TString   fGainDataName;

  enum {kNumber_of_azimuth = 33, kNumber_of_distance = 34};

  TArrayD*  fGainTable;           // Collection Efficiency data
  TArrayD*  fDistanceTable;       // Distance data
  TArrayD*  fAzimuthTable;        // Azimuth angle data
  TArrayI*  fNumberTable;         // Number of the data point
  TCanvas*  fCanvas;              // canvas for histograms
  TString   fPMTName;             // Name of the PMT
 
  // Renomalization Scale. 
  // For accounting PMT individual variances.

  Double_t fScale; //
  Double_t fNorm;  //

  ClassDef(RMOPMT2DGain, 1)    // Optical photon class

};

#endif
