// $Id: RMOPMTChargeResponse.h,v 1.6 2004/10/05 19:58:29 hoshina Exp $
#ifndef __RMOPMTChargeResponse__H__
#define __RMOPMTChargeResponse__H__

//*************************************************************************
//* ---------------------
//* RMOPMTChargeResponse Class
//* ---------------------
//* (Description)
//*  DOMPMTChargeResponse module is based on the charge response function.
//*  Current model of charge response function consists of gaussian component
//*  and exponential component. If you want to change the model, 
//*  define your charge response function and set it to the fChargeResponse.
//*     
//* (Requires)
//* (Provides)
//*	RMOPMTChargeResponse              : base class for modules
//* (Update Record)
//*	2003/12/22  K.Hoshina	Original version.
//*	2004/8/25   S.Yoshida	2 Dimensional Gain response included
//*************************************************************************

#include "RMOVModule.h"
#include "RMOElectron.h"
#include "RMOPMT2DGain.h"
#include "RMOPMTChargeBuf.h"
#include "TF1.h"
#include "TH1D.h"
#include "TCanvas.h"
#include "TVector3.h"

class RMOPMTChargeResponse : public RMOVModule {

public:

  RMOPMTChargeResponse();

  RMOPMTChargeResponse(TString& pmrGainFileName);

  virtual ~RMOPMTChargeResponse();

  virtual void Configure();
  virtual void Process();
  virtual void Finish();
  virtual void Draw();

  virtual const TObject  &GetBuffer() const       { return *fChargeBuf; }
  virtual Double_t        GetGain() const         { return fGain; } 
  virtual TString         GetGainDataName() const { return fGainDataName; } 

  virtual void      SetGain(Double_t gain)  { if(gain>0.0) fGain = gain;}
  virtual void      SetGainDataName(const TString &n)  { fGainDataName = n;}
  static  void      SetPe(Double_t val)        { fPe = val; }
  static  void      SetQt_ov_Q0(Double_t val)  { fQt_ov_Q0 = val; }
  static  void      SetSQ0_ov_Q0(Double_t val) { fSQ0_ov_Q0 = val; }
  static  void      SetTimeResol(Double_t val) { fTimeResol = val; }


protected:

  virtual RMOPMT2DGain    *GetGainMap() const  { return f2DGain; } 
  virtual TF1             *GetChargeResponse() { return fChargeResponse; } 
  virtual TH1D            *GetChargeHist()     { return fChargeHist; } 
  virtual RMOPMTChargeBuf *GetChargeBuf()      { return fChargeBuf; } 
  
private:

  void CreateSinglePEChargeResponse();
  void SmearTimeEdge(Double_t & time);

private:

  static Double_t fQt_ov_Q0;   //  qtau / q0
  static Double_t fSQ0_ov_Q0;  //  sq0 / q0 
  static Double_t fPe;         //  pe
  static Double_t fTimeResol;  // time resolution


  TString fGainDataName;

  RMOPMT2DGain     *f2DGain;           // Relative Gain as a function
                                       // of position on the cathode surface 
  Double_t         fGain;              // gain averaged all over 
                                       //the cathode surface

  TF1             *fChargeResponse;    // Function of charge responce 
  TH1D            *fChargeHist;        // gained charge hist
  RMOPMTChargeBuf *fChargeBuf;         // buffer of charge
  TCanvas         *fCanvas;            // Canvas for QResponse
  TCanvas         *fCanvas2;           // Canvas for QResponse

  ClassDef(RMOPMTChargeResponse, 1)    // Charge Response module

};

#endif
