// $Id: RMOPMTPhotoCathode.h,v 1.5 2004/10/05 19:58:29 hoshina Exp $
#ifndef __RMOPMTPhotoCathode__H__
#define __RMOPMTPhotoCathode__H__

//*************************************************************************
//* ---------------------
//* RMOPMTPhotoCathode Class
//* ---------------------
//* (Description)
//*     Photo Cathod module
//* (Requires)
//* (Provides)
//*	RMOPMTPhotoCathode              : base class for modules
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*     2004/8/23   S.Yoshida   The wavelength and photon hit location 
//*                             dependences are considered.
//*************************************************************************

#include <TVector3.h>
#include <TH2D.h>
#include <TCanvas.h>
#include "RMOVModule.h"
#include "RMOPMT2DCollectEff.h"
#include "RMOPMTQeDatum.h"
#include "RMOPMTPEBuf.h"


class RMOPMTPhotoCathode : public RMOVModule {

public:

  RMOPMTPhotoCathode();

  RMOPMTPhotoCathode(TString& pmrCEFileName);

  virtual ~RMOPMTPhotoCathode();

  virtual void Configure();
  virtual void Process();
  virtual void Finish();
  virtual void Draw();

  virtual const TObject &GetBuffer() const { return *fPEBuf; }
  
private:

  static const Int_t    kNXbins;    // No of Xbins of UniformityMap
  static const Int_t    kNYbins;    // No of Ybins of UniformityMap 
  static const Double_t kXmin;      // min of X-axis of UniformityMap
  static const Double_t kXmax;      // max of X-axis of UniformityMap
  static const Double_t kYmin;      // min of Y-axis of UniformityMap
  static const Double_t kYmax;      // max of Y-axis of UniformityMap

  TString               fCeDataName;  // name of Correction Efficiency File
  RMOPMT2DCollectEff*   f2DCE;        // Collection Efficiency as a function
                                      // of position on the cathode surface 
  RMOPMTQeDatum*        fQe;          // QE as a function of wavelength
  TH2D                 *fPEMap;       // 2D histgram of photo electrons
  RMOPMTPEBuf          *fPEBuf;       // buffer class 
  TCanvas              *fCanvas;      // canvas for histgrams

  ClassDef(RMOPMTPhotoCathode, 1)     // Photo cathode module class

};

#endif

