// $Id: RMOPMTQeDatum.h,v 1.2 2004/09/26 03:47:08 hoshina Exp $
#ifndef __RMOPMTQeDatum__H__
#define __RMOPMTQeDatum__H__

//*************************************************************************
//* ---------------------
//* RMOPMTQeDatum Class
//* ---------------------
//* (Description)
//*     module class for PMT Qe
//* (Requires)
//* (Provides)
//*	RMOPMTQeDatum              : Qe modules
//* (Update Record)
//*	2004/8/14  S.Yoshida	Original version.
//*************************************************************************
#include <iostream>
#include <fstream>
#include <TArrayD.h>
#include <TH1D.h>
#include <TCanvas.h>

#include "RMOVDatum.h"
#include "RMOUnit.h"

class RMOPMTQeDatum : public RMOVDatum {

public:

  RMOPMTQeDatum(): RMOVDatum(), fQeDataName("qe_representative.data"),
    fQeTable(0), fWaveLengthTable(0),
    fQeMap(0), fCanvas(0){
    fScale = 1.0; 
    ReadQeTable();
  }

  RMOPMTQeDatum(TString& fileName);

  virtual ~RMOPMTQeDatum();

  void Draw();

  Double_t       GetQe(Double_t waveLength);
  void           SetScale(Double_t scale){ fScale = scale;}
  virtual void   DumpInfo(Option_t *opt) {}

private:

  void ReadQeTable( );

  static const Int_t    kNXbins;    // No of Xbins of UniformityMap
  static const Double_t kXmin;      // min of X-axis of UniformityMap
  static const Double_t kXmax;      // max of X-axis of UniformityMap
  static const Int_t    kDegOfPolynominal; // degree of Polynominal interpolation
 
  TString               fQeDataName; // name of qe data file

  enum {kNumber_of_data = 47};

  TArrayD* fQeTable;              // Qe data
  TArrayD* fWaveLengthTable;      // Wavelength data
  TH1D*    fQeMap;                // 1D histgram of Qe
  TCanvas* fCanvas;               // canvas for histograms
 
  // Renomalization Scale. 
  // For accounting PMT individual variances.

  Double_t fScale;                // scale factor

  ClassDef(RMOPMTQeDatum, 1)    // Optical photon class

};

#endif
