// $Id: RMOPMTSingleWaveForm.cxx,v 1.4 2004/10/05 19:58:29 hoshina Exp $
//*************************************************************************
//* --------------------
//* RMOPMTSingleWaveForm
//* --------------------
//* (Description)
//*     Wave form class for single p.e.
//*     Current version is assuming gaussian pulse.
//*     To change pulse shape, overwrite Function(double*, double*) method.
//* (Requires)
//* (Provides)
//* (Update Record)
//*	2003/12/22  K.Hoshina	Original version.
//*************************************************************************

#include "RMOPMTSingleWaveForm.h"
#include <iostream>

ClassImp(RMOPMTSingleWaveForm)

using namespace std;

Double_t RMOPMTSingleWaveForm::fThreshold = (- 1. * kMICRO_VOLT) ; 

//=====================================================================
//* constructor -------------------------------------------------------

RMOPMTSingleWaveForm::RMOPMTSingleWaveForm( const Char_t  *name,
                                            Double_t xmin, Double_t xmax,
                                            Int_t npar)
                     :RMOVFunction(name, xmin, xmax, npar), RMOVAttDatum(),
                      fOriginID(kCerenkov)
{

}

//=====================================================================
//* destructor --------------------------------------------------------

RMOPMTSingleWaveForm::~RMOPMTSingleWaveForm()
{
}

//================================================================
// function Function
//================================================================

Double_t RMOPMTSingleWaveForm::Function(Double_t *x, Double_t *par) {

  Double_t norm   = par[0];
  Double_t sigma  = par[1];
  Double_t t0     = par[2];
  Double_t pedestal = par[3];
  Double_t signal = - norm / (TMath::Sqrt(2 * TMath::Pi()) * sigma)
                    * exp(- (x[0] - t0) * (x[0] - t0) / (2 * sigma * sigma))
                    + pedestal;

   return signal;

}

//=====================================================================
//* DrawCopy ----------------------------------------------------------

TF1* RMOPMTSingleWaveForm::DrawCopy(Option_t *option) const
{
//*-*-*-*Draw a copy of this function with its current attributes*-*-*
//       ========================================================
//  See TF1::DrawCopy to get more precise descriptions.
//

   RMOPMTSingleWaveForm *newf1 = new RMOPMTSingleWaveForm();
   Copy(*newf1);
   newf1->AppendPad(option);
   newf1->SetBit(kCanDelete);
   return newf1;
}

//=====================================================================
//* GetOriginName -----------------------------------------------------

TString  RMOPMTSingleWaveForm::GetOriginName(EOriginID id) const
{
   switch (id) {
      case (kCerenkov) :
         return TString("Cerenkov right");
         break;

      case (kRadioactive) :
         return TString("Radiation from glass");
         break;

      default :
         cerr << "RMOPMTSingleWaveForm::GetOriginName: Wrong ID!" << endl;
         abort();
   }
}

//=====================================================================
//* DumpInfo ----------------------------------------------------------

void RMOPMTSingleWaveForm::DumpInfo(Option_t *opt)
{

   cerr << "*-* RMOPMTSinglWaveForm::DumpInfo *-----------------" << endl;
   cerr << "* OriginID   :  " << GetOriginName(fOriginID) << endl;
   cerr << "* Amplitude  :  " << GetAmplitude() << " [V]" << endl;
   cerr << "* Threshold  :  " << fThreshold << " [V]" << endl;
   cerr << "* StartTime  :  " << GetStartTime() << " [sec]" << endl;
   cerr << "* PeakTime   :  " << GetPeakTime() << " [sec]" << endl;
   cerr << "* Sigma      :  " << GetSigma() << " [sec]" << endl;
   cerr << "* Pedestal   :  " << GetPedestal() << " [V]" << endl;

}


