// $Id: RMOPMTSingleWaveForm.h,v 1.3 2004/10/05 19:58:29 hoshina Exp $
#ifndef __RMOPMTSingleWaveForm__H__
#define __RMOPMTSingleWaveForm__H__

//*************************************************************************
//* ---------------------
//* RMOPMTSingleWaveForm Class
//* ---------------------
//* (Description)
//*     Wave form class for single p.e.
//*     Current version is assuming gaussian pulse.
//*     To change pulse shape, overwrite Function(double*, double*) method.
//* (Requires)
//* (Provides)
//*	RMOPMTSingleWaveForm              : single p.e. wave form class
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*************************************************************************

#include "RMOVFunction.h"
#include "RMOVAttDatum.h"
#include "RMOUnit.h"

class RMOPMTSingleWaveForm : public RMOVFunction, public RMOVAttDatum {

public:

   enum EOriginID { kCerenkov, kRadioactive };

   RMOPMTSingleWaveForm(const char* name = "RMOPMTSingleWaveForm", 
                        Double_t xmin = 0, 
                        Double_t xmax = 1.0e-7,  // 100ns
                        Int_t    npar = 4);

   virtual ~RMOPMTSingleWaveForm();

   virtual TF1             *DrawCopy(Option_t *option) const;
   virtual void             DumpInfo(Option_t *opt="");
   virtual Double_t         Function(Double_t *x, Double_t *par);
   inline virtual Double_t  GetAmplitude() const { return TMath::Abs(GetMinimum()); }
   inline virtual Double_t  GetPeakTime()  const { return GetMinimumX(); }
   inline virtual Double_t  GetPedestal()  const { return GetParameter(3); }  // par[3] is pedestal
   inline virtual EOriginID GetOriginID()  const { return fOriginID; }
   virtual TString          GetOriginName(EOriginID id) const;
   inline virtual Double_t  GetStartTime() const;
   inline virtual Double_t  GetSigma()     const { return GetParameter(1); }  // par[1] is sigma
   inline virtual Double_t  GetT0()        const { return GetParameter(2); }  // par[2] is T0 
   inline virtual Double_t  GetThreshold() const { return fThreshold; }  
   virtual void             SavePrimitive(ofstream &out, Option_t *option) {}
   inline virtual void      SetOriginID(EOriginID id)    { fOriginID = id; }
   static void              SetThreshold(Double_t thres) { fThreshold = thres; }

private:

   static Double_t  fThreshold;         // threshold voltage to get start time [V]
   EOriginID        fOriginID;          // origin of the pulse   

   ClassDef(RMOPMTSingleWaveForm, 1)    // Wave form class

};

//--------------------
// inline functions
//--------------------

Double_t RMOPMTSingleWaveForm::GetStartTime() const
{
   Double_t thres = (fThreshold >= GetPedestal() ? 
                     GetPedestal() - 1.*kMICRO_VOLT : fThreshold);
   return GetX(thres, GetXmin(), GetMinimumX());
}

#endif
