// $Id: RMOPMTWaveForm.h,v 1.5 2004/10/05 19:58:29 hoshina Exp $
#ifndef __RMOPMTWaveForm__H__
#define __RMOPMTWaveForm__H__

//*************************************************************************
//* ---------------------
//* RMOPMTWaveForm Class
//* ---------------------
//* (Description)
//*     Wave form module class. Generate single p.e pulse and store them
//*     to the RMOPMTWaveFormBuf. 
//*     Note that pulse integration is performed by RMOPMTWaveFormBuf.
//*       
//* (Requires)
//*     RMOPMTSingleWaveForm
//*     RMOPMTWaveFormBuf
//* (Provides)
//*	RMOPMTWaveForm              : Wave form module class
//* (Update Record)
//*	2003/12/15  K.Hoshina	Original version.
//*************************************************************************

#include "RMOVModule.h"
#include "RMOPMTWaveFormBuf.h"
#include "TF1.h"
#include "TH1D.h"
#include "TCanvas.h"
#include "TVector3.h"

class RMOPMTWaveForm : public RMOVModule {

public:

  RMOPMTWaveForm( const Char_t   *name  = "RMOPMTWaveForm", 
                  const Char_t   *title = "Wave form simulator");

  virtual ~RMOPMTWaveForm();

  virtual void            Configure();
  virtual void            Draw();
  virtual void            Finish();
  virtual const TObject  &GetBuffer() const { return *fWaveFormBuf; }
  inline virtual Double_t GetGround()     const { return fGround; }
  inline virtual Double_t GetSigma()      const { return fSigma; }
  inline virtual Double_t GetTerminator() const { return fTerminator; }
  inline virtual Double_t GetT0()         const { return fT0; }
  virtual void            Process();
  inline virtual void     SetGround(Double_t v)     { fGround = v; }
  inline virtual void     SetSigma(Double_t s)      { fSigma = s; }
  inline virtual void     SetTerminator(Double_t t) { fTerminator = t; }
  inline virtual void     SetT0(Double_t t)         { fT0 = t; }
 
protected:

  virtual Double_t           CalcNormalizationOfSingleWaveForm(Double_t charge);
  virtual RMOPMTWaveFormBuf *GetWaveFormBuf() { return fWaveFormBuf; }

private:

  Double_t  fSigma;                 // sigma of pulse
  Double_t  fTerminator;            // tarmination [ohm]
  Double_t  fT0;                    // T0
  Double_t  fGround;                // ground level [V]

  TH1D              *fNormHist;     // simulated gain
  RMOPMTWaveFormBuf *fWaveFormBuf;  // buffer of waveforms
  TCanvas           *fCanvas;       // Canvas for QResponse
  TCanvas           *fCanvas1;      // Canvas for QResponse

  ClassDef(RMOPMTWaveForm, 1)   // abstract base class for modules

};

#endif

